// This file was automatically generated by bifcl from /pobj/zeek-8.2.1/zeek-8.2.1/src/analyzer/protocol/mqtt/types.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_mqtt_types_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_mqtt_types_bif
#define _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_mqtt_types_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifType::Record::MQTT { extern zeek::IntrusivePtr<zeek::RecordType> ConnectMsg; }
namespace zeek::BifType::Record::MQTT { extern zeek::IntrusivePtr<zeek::RecordType> ConnectAckMsg; }
namespace zeek::BifType::Record::MQTT { extern zeek::IntrusivePtr<zeek::RecordType> PublishMsg; }

#endif
