// This file was automatically generated by bifcl from /pobj/zeek-8.2.1/zeek-8.2.1/src/file_analysis/analyzer/entropy/events.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_1_build_i386_src_file_analysis_analyzer_entropy_events_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_1_build_i386_src_file_analysis_analyzer_entropy_events_bif
#define _pobj_zeek_8_2_1_build_i386_src_file_analysis_analyzer_entropy_events_bif
#include "zeek/zeek-bif.h"
#endif
#endif

extern zeek::EventHandlerPtr file_entropy; 
namespace zeek::BifEvent { void enqueue_file_entropy(zeek::analyzer::Analyzer* analyzer, zeek::IntrusivePtr<zeek::Val> f, zeek::IntrusivePtr<zeek::Val> ent);  }

#endif
