// This file was automatically generated by bifcl from /pobj/zeek-8.2.1/zeek-8.2.1/src/analyzer/protocol/conn-size/events.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_conn_size_events_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_conn_size_events_bif
#define _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_conn_size_events_bif
#include "zeek/zeek-bif.h"
#endif
#endif

extern zeek::EventHandlerPtr conn_bytes_threshold_crossed; 
namespace zeek::BifEvent { void enqueue_conn_bytes_threshold_crossed(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek_uint_t threshold, int is_orig);  }
extern zeek::EventHandlerPtr conn_packets_threshold_crossed; 
namespace zeek::BifEvent { void enqueue_conn_packets_threshold_crossed(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek_uint_t threshold, int is_orig);  }
extern zeek::EventHandlerPtr conn_duration_threshold_crossed; 
namespace zeek::BifEvent { void enqueue_conn_duration_threshold_crossed(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, double threshold, int is_orig);  }
extern zeek::EventHandlerPtr conn_generic_packet_threshold_crossed; 
namespace zeek::BifEvent { void enqueue_conn_generic_packet_threshold_crossed(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek_uint_t threshold);  }

#endif
