// This file was automatically generated by bifcl from /pobj/zeek-8.2.1/zeek-8.2.1/src/logging/writers/none/none.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_1_build_i386_src_logging_writers_none_none_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_1_build_i386_src_logging_writers_none_none_bif
#define _pobj_zeek_8_2_1_build_i386_src_logging_writers_none_none_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifConst::LogNone { extern int debug; }

#endif
