// This file was automatically generated by bifcl from /pobj/zeek-8.2.1/zeek-8.2.1/src/analyzer/protocol/radius/events.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_radius_events_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_radius_events_bif
#define _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_radius_events_bif
#include "zeek/zeek-bif.h"
#endif
#endif

extern zeek::EventHandlerPtr radius_message; 
namespace zeek::BifEvent { void enqueue_radius_message(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::Val> result);  }
extern zeek::EventHandlerPtr radius_attribute; 
namespace zeek::BifEvent { void enqueue_radius_attribute(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek_uint_t attr_type, zeek::IntrusivePtr<zeek::StringVal> value);  }
namespace zeek::BifType::Vector::RADIUS { extern zeek::IntrusivePtr<zeek::VectorType> AttributeList; }
namespace zeek::BifType::Table::RADIUS { extern zeek::IntrusivePtr<zeek::TableType> Attributes; }
namespace zeek::BifType::Record::RADIUS { extern zeek::IntrusivePtr<zeek::RecordType> Message; }

#endif
