// This file was automatically generated by bifcl from /pobj/zeek-8.2.1/zeek-8.2.1/src/analyzer/protocol/dhcp/types.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_dhcp_types_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_dhcp_types_bif
#define _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_dhcp_types_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifType::Record::DHCP { extern zeek::IntrusivePtr<zeek::RecordType> Msg; }
namespace zeek::BifType::Vector::DHCP { extern zeek::IntrusivePtr<zeek::VectorType> Addrs; }
namespace zeek::BifType::Record::DHCP { extern zeek::IntrusivePtr<zeek::RecordType> SubOpt; }
namespace zeek::BifType::Vector::DHCP { extern zeek::IntrusivePtr<zeek::VectorType> SubOpts; }
namespace zeek::BifType::Record::DHCP { extern zeek::IntrusivePtr<zeek::RecordType> ClientFQDN; }
namespace zeek::BifType::Record::DHCP { extern zeek::IntrusivePtr<zeek::RecordType> ClientID; }
namespace zeek::BifType::Record::DHCP { extern zeek::IntrusivePtr<zeek::RecordType> Options; }

#endif
