// This file was automatically generated by bifcl from /pobj/zeek-8.2.1/zeek-8.2.1/src/analyzer/protocol/smb/smb2_com_session_setup.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_smb_smb2_com_session_setup_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_smb_smb2_com_session_setup_bif
#define _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_smb_smb2_com_session_setup_bif
#include "zeek/zeek-bif.h"
#endif
#endif

extern zeek::EventHandlerPtr smb2_session_setup_request; 
namespace zeek::BifEvent { void enqueue_smb2_session_setup_request(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::Val> hdr, zeek::IntrusivePtr<zeek::Val> request);  }
extern zeek::EventHandlerPtr smb2_session_setup_response; 
namespace zeek::BifEvent { void enqueue_smb2_session_setup_response(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::Val> hdr, zeek::IntrusivePtr<zeek::Val> response);  }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> SessionSetupRequest; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> SessionSetupResponse; }
namespace zeek::BifType::Record::SMB2 { extern zeek::IntrusivePtr<zeek::RecordType> SessionSetupFlags; }

#endif
