// This file was automatically generated by bifcl from /pobj/zeek-8.2.1/zeek-8.2.1/src/analyzer/protocol/http/functions.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_http_functions_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_http_functions_bif
#define _pobj_zeek_8_2_1_build_i386_src_analyzer_protocol_http_functions_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifFunc { extern zeek::ValPtr skip_http_entity_data_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc { extern zeek::ValPtr unescape_URI_bif(zeek::detail::Frame* frame, const zeek::Args*); }

#endif
