// This file was automatically generated by bifcl from /pobj/zeek-8.2.1/zeek-8.2.1/src/cluster/publish_on_change.bif (alternative mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_1_build_i386_src_cluster_publish_on_change_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_1_build_i386_src_cluster_publish_on_change_bif
#define _pobj_zeek_8_2_1_build_i386_src_cluster_publish_on_change_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifFunc::Cluster { extern zeek::ValPtr set_table_change_infos_forward_topic_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Cluster { extern zeek::ValPtr apply_table_change_infos_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Cluster { extern zeek::ValPtr __publish_table_bif(zeek::detail::Frame* frame, const zeek::Args*); }

#endif
