// This file was automatically generated by bifcl from /pobj/zeek-8.2.1/zeek-8.2.1/src/input/readers/benchmark/benchmark.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_1_build_i386_src_input_readers_benchmark_benchmark_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_1_build_i386_src_input_readers_benchmark_benchmark_bif
#define _pobj_zeek_8_2_1_build_i386_src_input_readers_benchmark_benchmark_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifConst::InputBenchmark { extern double factor; }
namespace zeek::BifConst::InputBenchmark { extern zeek_uint_t spread; }
namespace zeek::BifConst::InputBenchmark { extern double autospread; }
namespace zeek::BifConst::InputBenchmark { extern zeek_uint_t addfactor; }
namespace zeek::BifConst::InputBenchmark { extern zeek_uint_t stopspreadat; }
namespace zeek::BifConst::InputBenchmark { extern double timedspread; }

#endif
